@@ -14,14 +14,15 @@
 namespace Akonadi
 {
 
-class AgentFilterProxyModel;
+class AgentInstanceFilterProxyModel;
 class AgentInstanceWidget;
+class AgentFilterProxyModel;
 
 class ConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ConfigDialog(QWidget *parent = 0);
+    explicit ConfigDialog(QWidget *parent = nullptr);
 
 private slots:
     void onAddTriggered();
@@ -29,9 +30,10 @@ private slots:
     void onConfigureTriggered();
 
 private:
+    void applyContentTypes(Akonadi::AgentInstanceFilterProxyModel *model);
     void applyContentTypes(AgentFilterProxyModel *model);
 
-    Akonadi::AgentInstanceWidget *m_agentInstanceWidget;
+    Akonadi::AgentInstanceWidget *const m_agentInstanceWidget;
 };
 
 }
