@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include "akonadifakestorage.h"
 
 #include <QTimer>
@@ -37,8 +20,8 @@ class AkonadiFakeTransaction : public FakeJob
 {
     Q_OBJECT
 public:
-    explicit AkonadiFakeTransaction()
-        : FakeJob(),
+    explicit AkonadiFakeTransaction(QObject *parent = nullptr)
+        : FakeJob(parent),
           m_nextIdx(0)
     {
     }
@@ -149,9 +132,9 @@ KJob *AkonadiFakeStorage::updateItem(Akonadi::Item item, QObject *parent)
     return job;
 }
 
-KJob *AkonadiFakeStorage::removeItem(Akonadi::Item item)
+KJob *AkonadiFakeStorage::removeItem(Akonadi::Item item, QObject *parent)
 {
-    auto job = new FakeJob;
+    auto job = new FakeJob(parent);
     if (m_data->item(item.id()).isValid()) {
         Utils::JobHandler::install(job, [=] {
             if (!job->error()) {
@@ -303,17 +286,18 @@ KJob *AkonadiFakeStorage::removeCollection(Akonadi::Collection collection, QObje
     return job;
 }
 
-KJob *AkonadiFakeStorage::createTransaction()
+KJob *AkonadiFakeStorage::createTransaction(QObject *parent)
 {
-    auto job = new AkonadiFakeTransaction;
+    auto job = new AkonadiFakeTransaction(parent);
     Utils::JobHandler::install(job, noop);
     return job;
 }
 
 Akonadi::CollectionFetchJobInterface *AkonadiFakeStorage::fetchCollections(Akonadi::Collection collection,
-                                                                           Akonadi::StorageInterface::FetchDepth depth)
+                                                                           Akonadi::StorageInterface::FetchDepth depth,
+                                                                           QObject *parent)
 {
-    auto job = new AkonadiFakeCollectionFetchJob;
+    auto job = new AkonadiFakeCollectionFetchJob(parent);
     auto children = Akonadi::Collection::List();
 
     switch (depth) {
@@ -348,7 +332,7 @@ Akonadi::CollectionFetchJobInterface *AkonadiFakeStorage::fetchCollections(Akona
     return job;
 }
 
-Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItems(Akonadi::Collection collection)
+Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItems(Akonadi::Collection collection, QObject *parent)
 {
     auto items = m_data->childItems(findId(collection));
     std::transform(items.begin(), items.end(),
@@ -360,7 +344,7 @@ Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItems(Akonadi::Collecti
                        return result;
                    });
 
-    auto job = new AkonadiFakeItemFetchJob;
+    auto job = new AkonadiFakeItemFetchJob(parent);
     const auto behavior = m_data->storageBehavior().fetchItemsBehavior(collection.id());
     if (behavior == AkonadiFakeStorageBehavior::NormalFetch)
         job->setItems(items);
@@ -369,14 +353,14 @@ Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItems(Akonadi::Collecti
     return job;
 }
 
-Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItem(Akonadi::Item item)
+Akonadi::ItemFetchJobInterface *AkonadiFakeStorage::fetchItem(Akonadi::Item item, QObject *parent)
 {
     auto fullItem = m_data->item(findId(item));
     fullItem = m_data->reconstructItemDependencies(fullItem);
     // Force payload detach
     fullItem.setPayloadFromData(fullItem.payloadData());
 
-    auto job = new AkonadiFakeItemFetchJob;
+    auto job = new AkonadiFakeItemFetchJob(parent);
     const auto behavior = m_data->storageBehavior().fetchItemBehavior(item.id());
     if (behavior == AkonadiFakeStorageBehavior::NormalFetch)
         job->setItems(Akonadi::Item::List() << fullItem);
