@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include <testlib/qtest_gui_zanshin.h>
 
 #include <QCheckBox>
@@ -44,7 +27,7 @@ private slots:
 
         QVERIFY(filter.proxyModel());
         QVERIFY(!filter.proxyModel()->sourceModel());
-        QCOMPARE(filter.proxyModel()->filterRegExp(), QRegExp());
+        QCOMPARE(filter.proxyModel()->filterRegularExpression(), QRegularExpression());
         QCOMPARE(filter.proxyModel()->sortOrder(), Qt::AscendingOrder);
         QCOMPARE(filter.proxyModel()->sortType(), Presentation::TaskFilterProxyModel::TitleSort);
 
@@ -90,7 +73,7 @@ private slots:
         QTest::keyClicks(filterEdit, QStringLiteral("find me"));
 
         // THEN
-        QCOMPARE(filter.proxyModel()->filterRegExp().pattern(), QStringLiteral("find me"));
+        QCOMPARE(filter.proxyModel()->filterRegularExpression().pattern(), QStringLiteral("find\\ me"));
     }
 
     void shouldClearFilter()
@@ -107,7 +90,7 @@ private slots:
 
         // THEN
         QVERIFY(filterEdit->text().isEmpty());
-        QVERIFY(filter.proxyModel()->filterRegExp().pattern().isEmpty());
+        QVERIFY(filter.proxyModel()->filterRegularExpression().pattern().isEmpty());
     }
 
     void shouldShowExtension()
@@ -210,6 +193,22 @@ private slots:
         // THEN
         QVERIFY(filter.proxyModel()->showFutureTasks());
     }
+
+    void shouldShowDoneTasks()
+    {
+        // GIVEN
+        Widgets::FilterWidget filter;
+        filter.setShowDoneTasks(false);
+
+        // THEN
+        QVERIFY(!filter.proxyModel()->showDoneTasks());
+
+        // WHEN
+        filter.setShowDoneTasks(true);
+
+        // THEN
+        QVERIFY(filter.proxyModel()->showDoneTasks());
+    }
 };
 
 ZANSHIN_TEST_MAIN(FilterWidgetTest)
